
<!---
FrozenIsBool True
-->

##Example

Now for special settings in team and manage variables, note that 
pointers have always Inlets and Outlets teams to more easily set encapsulated horizontal pointers in the structure.